==> sri-d3m-0.4.6.tar.gz: sri-d3m-0.4.6/sri/graph/edgelist_to_graph.py <==
import typing

import networkx
from d3m import container
from d3m.metadata import base as meta_base
from d3m.metadata import hyperparams as meta_hyperparams
from d3m.primitive_interfaces import base as pi_base
from d3m.primitive_interfaces import transformer as pi_transformer

from sri.common import config
from sri.common import constants
from sri.common import util

Inputs = container.DataFrame  # container.List[networkx.Graph]
Outputs = container.DataFrame  # container.DataFrame[container.DataFrame]

class EdgeListToGraphHyperparams(meta_hyperparams.Hyperparams):
    pass

class EdgeListToGraph(pi_transformer.TransformerPrimitiveBase[Inputs, Outputs, EdgeListToGraphHyperparams]):
    """
    Convert edge lists to graphs.
    This is a inverse to the GraphToEdgeList primitive.
    """

    def __init__(self, *, _debug_options: typing.Dict = {}, hyperparams: EdgeListToGraphHyperparams, random_seed: int = 0) -> None:
        super().__init__(hyperparams = hyperparams, random_seed = random_seed)

        self._logger = util.get_logger(__name__)
        self._set_debug_options(_debug_options)

    def _set_debug_options(self, _debug_options):
        if (constants.DEBUG_OPTION_LOGGING_LEVEL in _debug_options):
            util.set_logging_level(_debug_options[constants.DEBUG_OPTION_LOGGING_LEVEL])

    def produce(self, *, inputs: Inputs, timeout: float = None, iterations: int = None) -> pi_base.CallResult[Outputs]:
        self._logger.debug("Starting produce")

        # TODO(eriq): Implement
        return pi_base.CallResult(container.DataFrame([], columns = ['graph']))

    metadata = meta_base.PrimitiveMetadata({
        # Required
        'id': '30f51c3a-d5fc-4bc1-b6bf-ab62b89489fd',
        'version': config.VERSION,
        'name': 'Edge List to Graph',
        'description': "Convert edge lists to graphs. This is a inverse to the GraphToEdgeList primitive.",
        'python_path': 'd3m.primitives.data.GraphToEdgeList',
        'primitive_family': meta_base.PrimitiveFamily.DATA_TRANSFORMATION,
        'algorithm_types': [
            meta_base.PrimitiveAlgorithmType.DATA_CONVERSION,
        ],
        'source': {
            'name': config.D3M_PERFORMER_TEAM,
            'uris': [ config.REPOSITORY ]
        },

        # Optional
        'keywords': [ 'preprocessing', 'primitive', 'graph', 'dataset', 'transformer' 'edge list' ],
        'installation': [ config.INSTALLATION ],
        'location_uris': [],
        'precondition': [ meta_base.PrimitiveEffects.NO_MISSING_VALUES ],
        'effects': [ meta_base.PrimitiveEffects.NO_MISSING_VALUES ],
        'hyperparms_to_tune': []
    })

==> sri-d3m-0.4.8.tar.gz: sri-d3m-0.4.8/sri/graph/edgelist_to_graph.py <==
import typing

import networkx
from d3m import container
from d3m.metadata import base as meta_base
from d3m.metadata import hyperparams as meta_hyperparams
from d3m.primitive_interfaces import base as pi_base
from d3m.primitive_interfaces import transformer as pi_transformer

from sri.common import config
from sri.common import constants
from sri.common import util

Inputs = container.DataFrame  # container.List[networkx.Graph]
Outputs = container.DataFrame  # container.DataFrame[container.DataFrame]

class EdgeListToGraphHyperparams(meta_hyperparams.Hyperparams):
    pass

class EdgeListToGraph(pi_transformer.TransformerPrimitiveBase[Inputs, Outputs, EdgeListToGraphHyperparams]):
    """
    Convert edge lists to graphs.
    This is a inverse to the GraphToEdgeList primitive.
    """

    def __init__(self, *, _debug_options: typing.Dict = {}, hyperparams: EdgeListToGraphHyperparams, random_seed: int = 0) -> None:
        super().__init__(hyperparams = hyperparams, random_seed = random_seed)

        self._logger = util.get_logger(__name__)
        self._set_debug_options(_debug_options)

    def _set_debug_options(self, _debug_options):
        if (constants.DEBUG_OPTION_LOGGING_LEVEL in _debug_options):
            util.set_logging_level(_debug_options[constants.DEBUG_OPTION_LOGGING_LEVEL])

    def produce(self, *, inputs: Inputs, timeout: float = None, iterations: int = None) -> pi_base.CallResult[Outputs]:
        self._logger.debug("Starting produce")

        # TODO(eriq): Implement
        return pi_base.CallResult(container.DataFrame([], columns = ['graph']))

    metadata = meta_base.PrimitiveMetadata({
        # Required
        'id': '30f51c3a-d5fc-4bc1-b6bf-ab62b89489fd',
        'version': config.VERSION,
        'name': 'Edge List to Graph',
        'description': "Convert edge lists to graphs. This is a inverse to the GraphToEdgeList primitive.",
        'python_path': 'd3m.primitives.data.EdgeToGraphList',
        'primitive_family': meta_base.PrimitiveFamily.DATA_TRANSFORMATION,
        'algorithm_types': [
            meta_base.PrimitiveAlgorithmType.DATA_CONVERSION,
        ],
        'source': {
            'name': config.D3M_PERFORMER_TEAM,
            'uris': [ config.REPOSITORY ]
        },

        # Optional
        'keywords': [ 'preprocessing', 'primitive', 'graph', 'dataset', 'transformer' 'edge list' ],
        'installation': [ config.INSTALLATION ],
        'location_uris': [],
        'precondition': [ meta_base.PrimitiveEffects.NO_MISSING_VALUES ],
        'effects': [ meta_base.PrimitiveEffects.NO_MISSING_VALUES ],
        'hyperparms_to_tune': []
    })
